@@ -15,7 +15,7 @@ use Chrome::DevToolsProtocol::Transport;
 use Scalar::Util 'weaken', 'isweak';
 use Try::Tiny;
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 our @CARP_NOT;
 
 =head1 NAME
@@ -447,12 +447,14 @@ sub on_response( $self, $connection, $message ) {
                 eval {
                     $listener->notify( $response );
                 };
+                $self->log('error', $@) if $@;
                 warn $@ if $@;
             };
             # re-weaken our references
             for (0..$#$listeners) {
                 weaken $listeners->[$_];
             };
+            $self->log('trace', "Message handled", $response);
 
             $handled++;
         };
@@ -846,7 +848,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 has 'protocol' => (
     is => 'ro',
