@@ -4,7 +4,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 =head1 NAME
 
@@ -12,16 +12,17 @@ Chrome::DevToolsProtocol::Transport - choose the best transport backend
 
 =cut
 
-our @loops = (
+our @loops;
+push @loops, (
     ['Mojo/IOLoop.pm'   => 'Chrome::DevToolsProtocol::Transport::Mojo' ],
     ['IO/Async.pm'      => 'Chrome::DevToolsProtocol::Transport::NetAsync'],
-    ['IO/Async/Loop.pm' => 'Chrome::DevToolsProtocol::Transport::Pipe::NetAsync'],
+    ['IO/Async/Loop.pm' => 'Chrome::DevToolsProtocol::Transport::NetAsync'],
     ['AnyEvent.pm'      => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
     ['AE.pm'            => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
     # native POE support would be nice
 );
 our $implementation;
-our $default = 'Chrome::DevToolsProtocol::Transport::AnyEvent';
+our $default = 'Chrome::DevToolsProtocol::Transport::NetAsync';
 
 =head1 METHODS
 
@@ -60,7 +61,7 @@ sub best_implementation( $class, @candidates ) {
     } @candidates;
 
     if( ! @applicable_implementations ) {
-        @applicable_implementations = map {$_->[1]} @candidates;
+        @applicable_implementations = ($default, map {$_->[1]} @candidates);
     }
 
     # Check which one we can load:
